pub struct MockProviderBillingVNextApi {
ProviderBillingVNextApi_expectations: MockProviderBillingVNextApi_ProviderBillingVNextApi,
}Fields
ProviderBillingVNextApi_expectations: MockProviderBillingVNextApi_ProviderBillingVNextApiImplementations
Sourceimpl MockProviderBillingVNextApi
impl MockProviderBillingVNextApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockProviderBillingVNextApi
impl MockProviderBillingVNextApi
Sourcepub fn expect_add_credit_via_bit_pay(&mut self) -> &mut Expectation
pub fn expect_add_credit_via_bit_pay(&mut self) -> &mut Expectation
Create an Expectation for mocking the add_credit_via_bit_pay method
Sourcepub fn expect_get_billing_address(&mut self) -> &mut Expectation
pub fn expect_get_billing_address(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_billing_address method
Sourcepub fn expect_get_credit(&mut self) -> &mut Expectation
pub fn expect_get_credit(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_credit method
Sourcepub fn expect_get_payment_method(&mut self) -> &mut Expectation
pub fn expect_get_payment_method(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_payment_method method
Sourcepub fn expect_get_warnings(&mut self) -> &mut Expectation
pub fn expect_get_warnings(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_warnings method
Sourcepub fn expect_update_billing_address(&mut self) -> &mut Expectation
pub fn expect_update_billing_address(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_billing_address method
Sourcepub fn expect_update_payment_method(&mut self) -> &mut Expectation
pub fn expect_update_payment_method(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_payment_method method